# API

## Models

```{eval-rst}
.. module:: biolord
.. currentmodule:: biolord

.. autosummary::
    :toctree: generated

    Biolord
```

## Modules

```{eval-rst}
.. currentmodule:: biolord

.. autosummary::
    :toctree: generated

    BiolordModule
    BiolordClassifyModule
```
